Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(565)

Unified Diff: third_party/WebKit/Source/modules/bluetooth/BluetoothSupplement.h

Issue 1399623003: bluetooth: Change BluetoothSupplement::from(ScriptState*) to from(LocalFrame*) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@my-origin
Patch Set: Add assert for supplement and changed to use executionContext Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/bluetooth/BluetoothSupplement.h
diff --git a/third_party/WebKit/Source/modules/bluetooth/BluetoothSupplement.h b/third_party/WebKit/Source/modules/bluetooth/BluetoothSupplement.h
index 609c022c27241c5170009f75cdf927f1d03f6034..08e8fb49bbe5fae05391949a1ee443ec0616ed18 100644
--- a/third_party/WebKit/Source/modules/bluetooth/BluetoothSupplement.h
+++ b/third_party/WebKit/Source/modules/bluetooth/BluetoothSupplement.h
@@ -24,9 +24,12 @@ public:
static void provideTo(LocalFrame&, WebBluetooth*);
- // Returns the WebBluetooth attached to the ScriptState's frame if that exists;
- // otherwise the Platform's WebBluetooth.
- static WebBluetooth* from(ScriptState*);
+ // Returns the WebBluetooth attached to the frame.
+ static WebBluetooth* from(LocalFrame*);
+
+ // Returns the WebBluetooth attached to the frame if the frame exists.
+ // Otherwise returns nullptr.
+ static WebBluetooth* fromScriptState(ScriptState*);
DECLARE_VIRTUAL_TRACE();

Powered by Google App Engine
This is Rietveld 408576698